@@ -3,7 +3,7 @@ use jsonrpsee::proc_macros::rpc;
 // Missing mandatory `item` field.
 #[rpc(client, server)]
 pub trait NoSubItem {
-	#[subscription(name = "sub", unsub = "unsub")]
+	#[subscription(name = "sub")]
 	fn sub(&self);
 }
 
